@@ -15,12 +15,10 @@
  *
  ****************************************************************************/
 
-struct canon_info_d
-{
-    char ident[64];
-};
 
-extern struct canon_info_d canon_info;
+
+
+
 
 
 /****************************************************************************
