@@ -12,6 +12,7 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    http://www.gnu.org/copyleft/gpl.html
 
  */
 
@@ -33,11 +34,14 @@
 *  serio.c
 */
 int InitSonyDSCF55(char *serial_port);
-int Write(char *buffer, int length);
-int Read(unsigned char *buffer, int *length);
-void DumpData(char *buffer, int length);
-int SetSpeed(int speed);
 void CloseSonyDSCF55(void);
+
+int Write(unsigned char *buffer, int length);
+int Read(unsigned char *buffer, int *length);
+
+void DumpData(unsigned char *buffer, int length);
+
+int SetSpeed(int speed);
 int dscSetSpeed(int);
 
 
