@@ -1,4 +1,4 @@
-/* $Id: gallery.c,v 1.18.2.2 1999/11/04 04:41:58 ole Exp $
+/* $Id: gallery.c,v 1.22 2000/03/06 21:23:06 ole Exp $
  *
  * gPhoto - free digital camera utility - http://www.gphoto.org/
 
@@ -40,6 +40,18 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $Log: gallery.c,v $
+ * Revision 1.22  2000/03/06 21:23:06  ole
+ * Released 0.4.3.
+ *
+ * Revision 1.21  1999/11/24 11:51:48  ole
+ * typo
+ *
+ * Revision 1.20  1999/11/23 11:17:29  ole
+ * Path fix by Jae <jgangemi@ccf.rutgers.edu>
+ *
+ * Revision 1.19  1999/11/20 16:28:43  ole
+ * Merged back changes
+ *
  * Revision 1.18.2.2  1999/11/04 04:41:58  ole
  * Changed hard coded path (/usr/local/share/gphoto/gallery) to
  * Makefile variable (GALLERYDIR).
@@ -465,8 +477,9 @@ Then, re-run the HTML Gallery.");
 	date[24] = '\0';
  	sprintf(outputdir,"%s",
 		(char*)gtk_object_get_data(GTK_OBJECT(dirlabel),"dir"));
-
-	sprintf(filename, "%s/%s",GALLERYDIR,theme);
+	
+	//jae
+	sprintf(filename, "%s/%s/",GALLERYDIR,theme);
 	dir = opendir(filename);
 	file = readdir(dir);
 	while (file != NULL) {
@@ -476,7 +489,7 @@ Then, re-run the HTML Gallery.");
 		    (strcmp(file->d_name, "thumbnail.html") != 0 ) &&
 		    (strcmp(file->d_name, ".") != 0 ) &&
 		    (strcmp(file->d_name, "..") != 0 )) {
-			sprintf(filename2, "%s%s", outputdir, file->d_name);
+			sprintf(filename2, "%s/%s", outputdir, file->d_name);
 			if (confirm_overwrite(filename2)) {
 				sprintf(cp, "cp %s%s %s", filename, file->d_name,
 					outputdir);
@@ -517,7 +530,10 @@ Then, re-run the HTML Gallery.");
 					j+1);
 				error_dialog(error);
 				sprintf(thumbnail, "Not Available");
-				sprintf(thumbnail_filename, "");
+				//jae
+				sprintf(thumbnail,
+		"<a href=\"picture-%03i.html\">Click Me<\\/a>",i+1);
+  				sprintf(thumbnail_filename, "");
 				sprintf(thumbnail_number, "%03i", i+1);
 			} else {
 				sprintf(thumbnail, 
