@@ -7,27 +7,27 @@
 /* The toolbar xpm icons */
 
 /*  #include "batch_save.xpm" */
-#include "close_image.xpm"
-#include "colors.xpm"
-#include "configure.xpm"
-#include "delete_images.xpm"
-#include "exit.xpm"
-#include "fliph.xpm"
-#include "flipv.xpm"
-#include "get_index.xpm"
-#include "get_index_empty.xpm"
-#include "get_selected_images.xpm"
-#include "help.xpm"
-#include "left_arrow.xpm"
-#include "mail_image.xpm"
-#include "open_image.xpm"
-#include "print_image.xpm"
-#include "resize.xpm"
-#include "right_arrow.xpm"
-#include "rotc.xpm"
-#include "rotcc.xpm"
-#include "save_current_image.xpm"
-#include "stop.xpm"
+#include "icons/close_image.xpm"
+#include "icons/colors.xpm"
+#include "icons/configure.xpm"
+#include "icons/delete_images.xpm"
+#include "icons/exit.xpm"
+#include "icons/fliph.xpm"
+#include "icons/flipv.xpm"
+#include "icons/get_index.xpm"
+#include "icons/get_index_empty.xpm"
+#include "icons/get_selected_images.xpm"
+#include "icons/help.xpm"
+#include "icons/left_arrow.xpm"
+#include "icons/mail_image.xpm"
+#include "icons/open_image.xpm"
+#include "icons/print_image.xpm"
+#include "icons/resize.xpm"
+#include "icons/right_arrow.xpm"
+#include "icons/rotc.xpm"
+#include "icons/rotcc.xpm"
+#include "icons/save_current_image.xpm"
+#include "icons/stop.xpm"
 
 /* #include "web_browse.xpm"   */
 /* #include "take_picture.xpm" */
